YARP 3.4.5 (2021-05-24)                                                {#v3_4_5}
=======================

[TOC]

YARP 3.4.5 Release Notes
========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v3.4.5%22).


Bug Fixes
---------

### Libraries

#### `sig`

##### `Image`

* Allocate the right amount of bytes for YUV422 images
* Decode vocabs when printing


### Devices

#### `BatteryWrapper`

* Data is now published on the yarp port even if some of the methods belonging
  to `IBattery` interface are not implemented (returning false).
  The only mandatory  method is `getBatteryStatus()`.

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v3.4.4..v3.4.5`):

```
     6	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     1	Marco Randazzo <marco.randazzo@iit.it>
```
